/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1beta1

import (
	"context"
	"time"

	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"

	v1beta1 "github.com/erda-project/erda/pkg/clientgo/apis/flinkoperator/v1beta1"
	scheme "github.com/erda-project/erda/pkg/clientgo/clientset/versioned/scheme"
)

// FlinkClustersGetter has a method to return a FlinkClusterInterface.
// A group's client should implement this interface.
type FlinkClustersGetter interface {
	FlinkClusters(namespace string) FlinkClusterInterface
}

// FlinkClusterInterface has methods to work with FlinkCluster resources.
type FlinkClusterInterface interface {
	Create(ctx context.Context, flinkCluster *v1beta1.FlinkCluster, opts v1.CreateOptions) (*v1beta1.FlinkCluster, error)
	Update(ctx context.Context, flinkCluster *v1beta1.FlinkCluster, opts v1.UpdateOptions) (*v1beta1.FlinkCluster, error)
	UpdateStatus(ctx context.Context, flinkCluster *v1beta1.FlinkCluster, opts v1.UpdateOptions) (*v1beta1.FlinkCluster, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.FlinkCluster, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1beta1.FlinkClusterList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.FlinkCluster, err error)
	FlinkClusterExpansion
}

// flinkClusters implements FlinkClusterInterface
type flinkClusters struct {
	client rest.Interface
	ns     string
}

// newFlinkClusters returns a FlinkClusters
func newFlinkClusters(c *FlinkoperatorV1beta1Client, namespace string) *flinkClusters {
	return &flinkClusters{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the flinkCluster, and returns the corresponding flinkCluster object, and an error if there is any.
func (c *flinkClusters) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.FlinkCluster, err error) {
	result = &v1beta1.FlinkCluster{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("flinkclusters").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of FlinkClusters that match those selectors.
func (c *flinkClusters) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.FlinkClusterList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1beta1.FlinkClusterList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("flinkclusters").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested flinkClusters.
func (c *flinkClusters) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("flinkclusters").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a flinkCluster and creates it.  Returns the server's representation of the flinkCluster, and an error, if there is any.
func (c *flinkClusters) Create(ctx context.Context, flinkCluster *v1beta1.FlinkCluster, opts v1.CreateOptions) (result *v1beta1.FlinkCluster, err error) {
	result = &v1beta1.FlinkCluster{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("flinkclusters").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(flinkCluster).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a flinkCluster and updates it. Returns the server's representation of the flinkCluster, and an error, if there is any.
func (c *flinkClusters) Update(ctx context.Context, flinkCluster *v1beta1.FlinkCluster, opts v1.UpdateOptions) (result *v1beta1.FlinkCluster, err error) {
	result = &v1beta1.FlinkCluster{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("flinkclusters").
		Name(flinkCluster.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(flinkCluster).
		Do(ctx).
		Into(result)
	return
}

// UpdateStatus was generated because the type contains a Status member.
// Add a +genclient:noStatus comment above the type to avoid generating UpdateStatus().
func (c *flinkClusters) UpdateStatus(ctx context.Context, flinkCluster *v1beta1.FlinkCluster, opts v1.UpdateOptions) (result *v1beta1.FlinkCluster, err error) {
	result = &v1beta1.FlinkCluster{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("flinkclusters").
		Name(flinkCluster.Name).
		SubResource("status").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(flinkCluster).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the flinkCluster and deletes it. Returns an error if one occurs.
func (c *flinkClusters) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("flinkclusters").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *flinkClusters) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("flinkclusters").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched flinkCluster.
func (c *flinkClusters) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.FlinkCluster, err error) {
	result = &v1beta1.FlinkCluster{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("flinkclusters").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
